@@ -12,10 +12,11 @@ import os.path as osp
 import sys
 
 # Local imports
-from spyder.config.base import (
-    _, DEV, is_pynsist, running_in_ci, running_under_pytest)
+from spyder.api.translations import _
+from spyder.config.base import running_in_ci, is_conda_based_app
 from spyder.utils import programs
 
+
 HERE = osp.dirname(osp.abspath(__file__))
 
 # =============================================================================
@@ -30,52 +31,58 @@ PLUGIN = 'spyder plugins'
 # Versions
 # =============================================================================
 # Hard dependencies
-APPLAUNCHSERVICES_REQVER = '>=0.1.7'
+AIOHTTP_REQVER = '>=3.11.2'
+APPLAUNCHSERVICES_REQVER = '>=0.3.0'
+ASYNCSSH_REQVER = '>=2.14.0,<3.0.0'
 ATOMICWRITES_REQVER = '>=1.2.0'
+BCRYPT_REQVER = ">=4.3.0"
 CHARDET_REQVER = '>=2.0.0'
 CLOUDPICKLE_REQVER = '>=0.5.0'
 COOKIECUTTER_REQVER = '>=1.6.0'
 DIFF_MATCH_PATCH_REQVER = '>=20181111'
-# None for pynsist install for now
-# (check way to add dist.info/egg.info from packages without wheels available)
-INTERVALTREE_REQVER = None if is_pynsist() else '>=3.0.2'
-IPYTHON_REQVER = ">=7.6.0"
-JEDI_REQVER = '>=0.17.2;<0.19.0'
+IMPORTLIB_METADATA_REQVER = '>=4.6.0'
+INTERVALTREE_REQVER = '>=3.0.2'
+IPYTHON_REQVER = ">=8.15.0,<10.0.0,!=8.17.1,!=9.1.0,!=9.2.0,!=9.3.0,!=9.4.0"
+IPYTHON_PYGMENTS_LEXERS_REQVER = ">=1.0"
+JEDI_REQVER = '>=0.17.2,<0.20.0'
+JELLYFISH_REQVER = '>=0.7'
 JSONSCHEMA_REQVER = '>=3.2.0'
 KEYRING_REQVER = '>=17.0.0'
 NBCONVERT_REQVER = '>=4.0'
 NUMPYDOC_REQVER = '>=0.6.0'
-PARAMIKO_REQVER = '>=2.4.0'
-PARSO_REQVER = '>=0.7.0;<0.9.0'
+PACKAGING_REQVER = '>=20.0'
+PARSO_REQVER = '>=0.7.0,<0.9.0'
 PEXPECT_REQVER = '>=4.4.0'
 PICKLESHARE_REQVER = '>=0.4'
 PSUTIL_REQVER = '>=5.3'
+PYGITHUB_REQVER = '>=2.3.0'
 PYGMENTS_REQVER = '>=2.0'
-PYLINT_REQVER = '>=2.5.0'
-PYLSP_REQVER = '>=1.2.2;<1.3.0'
-PYLSP_BLACK_REQVER = '>=1.0.0'
+PYLINT_REQVER = '>=3.1,<4'
+PYLINT_VENV_REQVER = '>=3.0.2'
+PYLSP_REQVER = '>=1.13.2,<1.14.0'
+PYLSP_BLACK_REQVER = '>=2.0.0,<3.0.0'
+PYLSP_RUFF_REQVER = '>=2.3.0,<3.0.0'
 PYLS_SPYDER_REQVER = '>=0.4.0'
+PYUCA_REQVER = '>=1.2'
 PYXDG_REQVER = '>=0.26'
-PYZMQ_REQVER = '>=17'
-QDARKSTYLE_REQVER = '>=3.0.2'
-QSTYLIZER_REQVER = '>=0.1.10'
-QTAWESOME_REQVER = '>=1.0.2'
-QTCONSOLE_REQVER = '>=5.1.0'
-QTPY_REQVER = '>=1.5.0'
+PYZMQ_REQVER = '>=24.0.0'
+QDARKSTYLE_REQVER = '>=3.2.0,<3.3.0'
+QSTYLIZER_REQVER = '>=0.2.2'
+QTAWESOME_REQVER = '>=1.4.0,<1.5.0'
+QTCONSOLE_REQVER = '>=5.7.0,<5.8.0'
+QTPY_REQVER = '>=2.4.0'
 RTREE_REQVER = '>=0.9.7'
-SETUPTOOLS_REQVER = '>=49.6.0'
-SPHINX_REQVER = '>=0.6.6'
-SPYDER_KERNELS_REQVER = '>=2.1.1;<2.2.0'
+SPHINX_REQVER = '>=7.2.0'
+SPYDER_KERNELS_REQVER = '>=3.1.2,<3.2.0'
+SUPERQT_REQVER = '>=0.6.2,<1.0.0'
 TEXTDISTANCE_REQVER = '>=4.2.0'
 THREE_MERGE_REQVER = '>=0.1.1'
-# None for pynsist install for now
-# (check way to add dist.info/egg.info from packages without wheels available)
-WATCHDOG_REQVER = None if is_pynsist() else '>=0.10.3'
-
+WATCHDOG_REQVER = '>=0.10.3'
+YARL_REQVER = '>=1.9.4'
 
 # Optional dependencies
 CYTHON_REQVER = '>=0.21'
-MATPLOTLIB_REQVER = '>=2.0.0'
+MATPLOTLIB_REQVER = '>=3.0.0'
 NUMPY_REQVER = '>=1.7'
 PANDAS_REQVER = '>=1.1.1'
 SCIPY_REQVER = '>=0.17.0'
@@ -90,15 +97,27 @@ SYMPY_REQVER = '>=0.7.3'
 # =============================================================================
 # List of descriptions
 DESCRIPTIONS = [
+    {'modname': 'aiohttp',
+     'package_name': 'aiohttp',
+     'features': _('Async http client/server'),
+     'required_version': AIOHTTP_REQVER},
     {'modname': "applaunchservices",
      'package_name': "applaunchservices",
      'features': _("Notify macOS that Spyder can open Python files"),
      'required_version': APPLAUNCHSERVICES_REQVER,
-     'display': sys.platform == "darwin"},
+     'display': sys.platform == "darwin" and not is_conda_based_app()},
+    {'modname': 'asyncssh',
+     'package_name': 'asyncssh',
+     'features': _('Connect to remote kernels through SSH'),
+     'required_version': ASYNCSSH_REQVER},
     {'modname': "atomicwrites",
      'package_name': "atomicwrites",
      'features': _("Atomic file writes in the Editor"),
      'required_version': ATOMICWRITES_REQVER},
+    {'modname': "bcrypt",
+     'package_name': "bcrypt",
+     'features': _("Decrypt passphrase of SSH key files"),
+     'required_version': BCRYPT_REQVER},
     {'modname': "chardet",
      'package_name': "chardet",
      'features': _("Character encoding auto-detection for the Editor"),
@@ -115,6 +134,10 @@ DESCRIPTIONS = [
      'package_name': "diff-match-patch",
      'features': _("Compute text file diff changes during edition"),
      'required_version': DIFF_MATCH_PATCH_REQVER},
+    {'modname': 'importlib_metadata',
+     'package_name': 'importlib-metadata',
+     'features': _('Access the metadata for a Python package'),
+     'required_version': IMPORTLIB_METADATA_REQVER},
     {'modname': "intervaltree",
      'package_name': "intervaltree",
      'features': _("Compute folding range nesting levels"),
@@ -123,10 +146,18 @@ DESCRIPTIONS = [
      'package_name': "IPython",
      'features': _("IPython interactive python environment"),
      'required_version': IPYTHON_REQVER},
+    {'modname': "ipython_pygments_lexers",
+     'package_name': "ipython_pygments_lexers",
+     'features': _("IPython lexers for syntax highlighting"),
+     'required_version': IPYTHON_PYGMENTS_LEXERS_REQVER},
     {'modname': "jedi",
      'package_name': "jedi",
      'features': _("Main backend for the Python Language Server"),
      'required_version': JEDI_REQVER},
+    {'modname': "jellyfish",
+     'package_name': "jellyfish",
+     'features': _("Optimize algorithms for folding"),
+     'required_version': JELLYFISH_REQVER},
     {'modname': 'jsonschema',
      'package_name': 'jsonschema',
      'features': _('Verify if snippets files are valid'),
@@ -144,11 +175,10 @@ DESCRIPTIONS = [
      'package_name': "numpydoc",
      'features': _("Improve code completion for objects that use Numpy docstrings"),
      'required_version': NUMPYDOC_REQVER},
-    {'modname': "paramiko",
-     'package_name': "paramiko",
-     'features': _("Connect to remote kernels through SSH"),
-     'required_version': PARAMIKO_REQVER,
-     'display': os.name == 'nt'},
+    {'modname': "packaging",
+     'package_name': "packaging",
+     'features': _("Compare version numbers of Python packages"),
+     'required_version': PACKAGING_REQVER},
     {'modname': "parso",
      'package_name': "parso",
      'features': _("Python parser that supports error recovery and "
@@ -166,6 +196,10 @@ DESCRIPTIONS = [
      'package_name': "psutil",
      'features': _("CPU and memory usage info in the status bar"),
      'required_version': PSUTIL_REQVER},
+    {'modname': "github",
+     'package_name': "pygithub",
+     'features': _("Python API for Github REST API"),
+     'required_version': PYGITHUB_REQVER},
     {'modname': "pygments",
      'package_name': "pygments",
      'features': _("Syntax highlighting for a lot of file types in the Editor"),
@@ -174,6 +208,11 @@ DESCRIPTIONS = [
      'package_name': "pylint",
      'features': _("Static code analysis"),
      'required_version': PYLINT_REQVER},
+    {'modname': "pylint_venv",
+     'package_name': "pylint-venv",
+     'features': _("Use the same Pylint installation with different virtual"
+                   " environments"),
+     'required_version': PYLINT_VENV_REQVER},
     {'modname': 'pylsp',
      'package_name': 'python-lsp-server',
      'features': _("Code completion and linting for the Editor"),
@@ -183,10 +222,18 @@ DESCRIPTIONS = [
      'features': _("Autoformat Python files in the Editor with the Black "
                    "package"),
      'required_version': PYLSP_BLACK_REQVER},
+    {'modname': 'pylsp_ruff',
+     'package_name': 'python-lsp-ruff',
+     'features': _("Provide linting with the Ruff package"),
+     'required_version': PYLSP_RUFF_REQVER},
     {'modname': 'pyls_spyder',
      'package_name': 'pyls-spyder',
      'features': _('Spyder plugin for the Python LSP Server'),
      'required_version': PYLS_SPYDER_REQVER},
+    {'modname': 'pyuca',
+     'package_name': 'pyuca',
+     'features': _('Properly sort lists of non-English strings'),
+     'required_version': PYUCA_REQVER},
     {'modname': "xdg",
      'package_name': "pyxdg",
      'features': _("Parse desktop files on Linux"),
@@ -218,12 +265,8 @@ DESCRIPTIONS = [
      'required_version': QTPY_REQVER},
     {'modname': "rtree",
      'package_name': "rtree",
-     'features': _("Fast access to code snippets regions"),
+     'features': _("Fast access to code snippet regions"),
      'required_version': RTREE_REQVER},
-    {'modname': "setuptools",
-     'package_name': "setuptools",
-     'features': _("Determine package version"),
-     'required_version': SETUPTOOLS_REQVER},
     {'modname': "sphinx",
      'package_name': "sphinx",
      'features': _("Show help for objects in the Editor and Consoles in a dedicated pane"),
@@ -232,6 +275,10 @@ DESCRIPTIONS = [
      'package_name': "spyder-kernels",
      'features': _("Jupyter kernels for the Spyder console"),
      'required_version': SPYDER_KERNELS_REQVER},
+     {'modname': "superqt",
+     'package_name': "superqt",
+     'features': _("Special widgets and utilities for PyQt applications"),
+     'required_version': SUPERQT_REQVER},
     {'modname': 'textdistance',
      'package_name': "textdistance",
      'features': _('Compute distances between strings'),
@@ -244,6 +291,10 @@ DESCRIPTIONS = [
      'package_name': "watchdog",
      'features': _("Watch file changes on project directories"),
      'required_version': WATCHDOG_REQVER},
+     {'modname': "yarl",
+     'package_name': "yarl",
+     'features': _("URL parsing and changing"),
+     'required_version': YARL_REQVER},
 ]
 
 
@@ -286,10 +337,11 @@ DESCRIPTIONS += [
 # Code
 # =============================================================================
 class Dependency(object):
-    """Spyder's dependency
+    """
+    Spyder's dependency
 
-    version may starts with =, >=, > or < to specify the exact requirement ;
-    multiple conditions may be separated by ';' (e.g. '>=0.13;<1.0')"""
+    Version may starts with =, >=, > or < to specify the exact requirement;
+    multiple conditions may be separated by ',' (e.g. '>=0.13,<1.0')"""
 
     OK = 'OK'
     NOK = 'NOK'
@@ -302,9 +354,23 @@ class Dependency(object):
         self.required_version = required_version
         self.kind = kind
 
+        # Although this is not necessarily the case, it's customary that a
+        # package's distribution name be it's name on PyPI with hyphens
+        # replaced by underscores.
+        # Example:
+        # * Package name: python-lsp-black.
+        # * Distribution name: python_lsp_black
+        self.distribution_name = self.package_name.replace('-', '_')
+
         if installed_version is None:
             try:
                 self.installed_version = programs.get_module_version(modname)
+                if not self.installed_version:
+                    # Use get_package_version and the distribution name
+                    # because there are cases for which the version can't
+                    # be obtained from the module (e.g. pylsp_black).
+                    self.installed_version = programs.get_package_version(
+                        self.distribution_name)
             except Exception:
                 # NOTE: Don't add any exception type here!
                 # Modules can fail to import in several ways besides
@@ -315,9 +381,16 @@ class Dependency(object):
 
     def check(self):
         """Check if dependency is installed"""
+        if self.modname == 'spyder_kernels':
+            # TODO: Remove when spyder-kernels 3 is released!
+            return True
         if self.required_version:
-            return programs.is_module_installed(self.modname,
-                                                self.required_version)
+            installed = programs.is_module_installed(
+                self.modname,
+                self.required_version,
+                distribution_name=self.distribution_name
+            )
+            return installed
         else:
             return True
 
@@ -344,9 +417,14 @@ def add(modname, package_name, features, required_version,
     """Add Spyder dependency"""
     global DEPENDENCIES
     for dependency in DEPENDENCIES:
+        # Avoid showing an unnecessary error when running our tests.
+        if running_in_ci() and 'spyder_boilerplate' in modname:
+            continue
+
         if dependency.modname == modname:
-            raise ValueError("Dependency has already been registered: %s"\
-                             % modname)
+            raise ValueError(
+                f"Dependency has already been registered: {modname}")
+
     DEPENDENCIES += [Dependency(modname, package_name, features,
                                 required_version,
                                 installed_version, kind)]
@@ -381,15 +459,17 @@ def status(deps=DEPENDENCIES, linesep=os.linesep):
     maxwidth += 1
     text = ""
     prev_order = '-1'
-    for order, title, version in sorted(data,
-                                        key=lambda x: x[0] + x[1].lower()):
+    for order, title, version in sorted(
+            data, key=lambda x: x[0] + x[1].lower()):
         if order != prev_order:
-            text += '{sep}# {name}:{sep}'.format(
-                sep=linesep, name=order_dep[order].capitalize())
+            name = order_dep[order]
+            if name == MANDATORY:
+                text += f'# {name.capitalize()}:{linesep}'
+            else:
+                text += f'{linesep}# {name.capitalize()}:{linesep}'
             prev_order = order
 
-        text += '{title}:  {version}{linesep}'.format(
-            title=title.ljust(maxwidth), version=version, linesep=linesep)
+        text += f'{title.ljust(maxwidth)}:  {version}{linesep}'
 
     # Remove spurious linesep when reporting deps to Github
     if not linesep == '<br>':
@@ -402,14 +482,6 @@ def missing_dependencies():
     """Return the status of missing dependencies (if any)"""
     missing_deps = []
     for dependency in DEPENDENCIES:
-        # Skip checking dependencies for which we have subrepos
-        if (DEV or running_under_pytest()) and not running_in_ci():
-            repo_path = osp.normpath(osp.join(HERE, '..'))
-            subrepos_path = osp.join(repo_path, 'external-deps')
-            subrepos = os.listdir(subrepos_path)
-            if dependency.package_name in subrepos:
-                continue
-
         if dependency.kind != OPTIONAL and not dependency.check():
             missing_deps.append(dependency)
 
