@@ -18,6 +18,7 @@ import functools
 import logging
 import os
 import os.path as osp
+import re
 from string import Template
 import time
 import traceback
@@ -74,11 +75,6 @@ BLANK = open(osp.join(TEMPLATES_PATH, 'blank.html')).read()
 LOADING = open(osp.join(TEMPLATES_PATH, 'loading.html')).read()
 KERNEL_ERROR = open(osp.join(TEMPLATES_PATH, 'kernel_error.html')).read()
 
-try:
-    time.monotonic  # time.monotonic new in 3.3
-except AttributeError:
-    time.monotonic = time.time
-
 
 # ----------------------------------------------------------------------------
 # Client widget
@@ -355,14 +351,26 @@ class ClientWidget(QWidget, SaveHistoryMixin, SpyderWidgetMixin):  # noqa: PLR09
                     section='workingdir'
                 )
 
-        if osp.isdir(cwd_path) and not self.shellwidget.is_remote():
-            self.shellwidget.set_cwd(cwd_path, emit_cwd_change=emit_cwd_change)
-        else:
+        if self.is_remote():
             # Use the remote machine files API to get the home directory (`~`)
             # absolute path.
             self._get_remote_home_directory().connect(
                 self._on_remote_home_directory
             )
+        else:
+            # We can't set the cwd when connecting to remote kernels directly.
+            if not (
+                self.kernel_handler.password or self.kernel_handler.sshkey
+            ):
+                # Check if cwd exists, else use home dir.
+                # Fixes spyder-ide/spyder#25120.
+                if not osp.isdir(cwd_path):
+                    cwd_path = get_home_dir()
+                    emit_cwd_change = True
+
+                self.shellwidget.set_cwd(
+                    cwd_path, emit_cwd_change=emit_cwd_change
+                )
 
     # ---- Public API
     # -------------------------------------------------------------------------
@@ -509,6 +517,9 @@ class ClientWidget(QWidget, SaveHistoryMixin, SpyderWidgetMixin):  # noqa: PLR09
         if self.is_benign_error(error):
             return
 
+        if self.is_warning_message(error):
+            return
+
         InstallerIPythonKernelError(error)
 
         # Replace end of line chars with <br>
@@ -591,6 +602,14 @@ class ClientWidget(QWidget, SaveHistoryMixin, SpyderWidgetMixin):  # noqa: PLR09
 
         return any([err in error for err in benign_errors])
 
+    def is_warning_message(self, error):
+        """Decide if a message contains a warning in order to filter it."""
+        warning_pattern = re.compile(
+            r"(?:^|\s)(?:[A-Za-z]*Warning:|"
+            r"(?<=\s)WARNING(?=\s))(?:\:)?(?=\s|$)"
+        )
+        return warning_pattern.search(error)
+
     def get_name(self):
         """Return client name"""
         if self.given_name is None:
@@ -682,14 +701,17 @@ class ClientWidget(QWidget, SaveHistoryMixin, SpyderWidgetMixin):  # noqa: PLR09
 
         self.shutdown(is_last_client, close_console=close_console)
 
-        # Close jupyter api regardless of the kernel state
-        if self.is_remote() and not self._jupyter_api.closed:
-            AsyncDispatcher(
-                loop=self._jupyter_api.session._loop, early_return=False
-            )(self._jupyter_api.close)()
-            AsyncDispatcher(
-                loop=self._files_api.session._loop, early_return=False
-            )(self._files_api.close)()
+        # Close jupyter and files apis regardless of the kernel state
+        if self.is_remote():
+            if not self._jupyter_api.closed:
+                AsyncDispatcher(
+                    loop=self._jupyter_api.session._loop, early_return=False
+                )(self._jupyter_api.close)()
+
+            if not self._files_api.closed:
+                AsyncDispatcher(
+                    loop=self._files_api.session._loop, early_return=False
+                )(self._files_api.close)()
 
         # Prevent errors in our tests
         try:
